fox_enum library
A library for FoxEnum, a Flutter package that provides utilities for working with enums.
Enums
- FlutterPlatforms
- Flutter platforms understood by the CLI.
A library for FoxEnum, a Flutter package that provides utilities for working with enums.