AppLoggerProgress class

Minimal progress handle backed by AppLogger.

Constructors

AppLoggerProgress(AppLogger _logger, String message)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

complete([String? message]) → void
fail([String? message]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited