FoxLogRecord class
Constructors
- FoxLogRecord({required DateTime timestamp, required LogLevel level, required String message, Object? error, StackTrace? stackTrace, String? source})
-
const
Properties
- error → Object?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → LogLevel
-
final
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
final
- stackTrace → StackTrace?
-
final
- timestamp → DateTime
-
final
Methods
-
generateTextMessage(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited