LogLevel enum
Values
- verbose → const LogLevel
-
const LogLevel(0, 'VERBOSE', '\x1B[90m') - debug → const LogLevel
-
const LogLevel(1, 'DEBUG', '\x1B[36m') - info → const LogLevel
-
const LogLevel(2, 'INFO', '\x1B[32m') - warning → const LogLevel
-
const LogLevel(3, 'WARNING', '\x1B[33m') - error → const LogLevel
-
const LogLevel(4, 'ERROR', '\x1B[31m') - critical → const LogLevel
-
const LogLevel(5, 'CRITICAL', '\x1B[35m')
Properties
- ansiColor → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - priority → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited