fox_sdk library

fox_sdk, Fox SDK for Flutter

# activate fox_sdk
dart pub global activate fox_sdk

# see usage
fox --help

Classes

PlatformResolver
Resolves the current Flutter platform when running inside Flutter.

Properties

isAndroid bool
Checks if the current platform is Android.
final
isDarwin bool
Checks if the current platform is a Darwin platform (macOS or iOS).
final
isDesktop bool
Checks if the current platform is a desktop platform.
final
isIOS bool
Checks if the current platform is iOS.
final
isLinux bool
Checks if the current platform is Linux.
final
isMacOS bool
Checks if the current platform is macOS.
final
isMobile bool
Checks if the current platform is a mobile platform (Android or iOS).
final
isWeb bool
Checks if the current platform is the web.
final
isWindows bool
Checks if the current platform is Windows.
final