isDarwin top-level property
Checks if the current platform is a Darwin platform (macOS or iOS).
Implementation
final bool isDarwin = PlatformResolver.isMacOS || PlatformResolver.isIOS;
Checks if the current platform is a Darwin platform (macOS or iOS).
final bool isDarwin = PlatformResolver.isMacOS || PlatformResolver.isIOS;