isDesktop top-level property
Checks if the current platform is a desktop platform.
Implementation
final bool isDesktop = PlatformResolver.isDesktop;
Checks if the current platform is a desktop platform.
final bool isDesktop = PlatformResolver.isDesktop;