FoxLoggerSettings class
Constructors
Properties
- defaultTitle → String
-
final
- enable → bool
-
final
- enableColors → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → LogLevel
-
final
- lineSymbol → String
-
final
- maxLineWidth → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? defaultTitle, bool? enable, LogLevel? level, String? lineSymbol, int? maxLineWidth, bool? enableColors}) → FoxLoggerSettings -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited